Examples
========

All of these examples are contained in the `doc/examples/` subdirectory of the
`pylcp` package as `Juypter` notebooks.  The original source makes an excellent
starting point for building your own script for `pylcp`.

Basic Examples
--------------

These examples focus on internal dynamics in an atom, without concerning itself
with the motion.

.. toctree::
   :maxdepth: 1

   examples/basics/01_power_broadening.ipynb
   examples/basics/02_rabi_flopping.ipynb
   examples/basics/03_damped_rabi_flopping.ipynb
   examples/basics/04_adiabatic_passage.ipynb
   examples/basics/06_optical_pumping.ipynb
   examples/basics/07_three_level_susceptibility.ipynb
   examples/basics/08_stirap.ipynb

Optical Molasses
----------------

These examples concern the simplest laser cooling setup: a one-dimensional
optical molasses for slowing atoms.

.. toctree::
   :maxdepth: 1

   examples/molasses/00_two_level_1D_molasses.ipynb
   examples/molasses/01_F0_to_F1_1D_molasses.ipynb
   examples/molasses/02_F2_to_F3_1D_molasses.ipynb
   examples/molasses/03_F_to_Fp_1D_molasses.ipynb

Magneto-optical traps
---------------------

These examples focus on understanding the magneto-optical trap.

.. toctree::
   :maxdepth: 1

   examples/MOTs/00_F0_to_F1_1D_MOT_forces.ipynb
   examples/MOTs/01_F0_to_F1_1D_MOT_capture.ipynb
   examples/MOTs/02_F0_to_F1_1D_MOT_OBE.ipynb
   examples/MOTs/03_F0_to_F1_3D_MOT_OBE_temperature.ipynb
   examples/MOTs/04_Fn_to_Fm_1D_MOT.ipynb
   examples/MOTs/05_Fm_to_Fn_3D_MOT.ipynb
   examples/MOTs/06_real_atoms_3D_MOT.ipynb
   examples/MOTs/07_two_color_MOT.ipynb
   examples/MOTs/10_recoil_limited_MOT.ipynb
   examples/MOTs/20_CaF_MOT.ipynb

Other examples
--------------

.. toctree::
   :maxdepth: 1

   examples/bichromatic/00_bichromatic_forces.ipynb
